Player = class("Player",StatefulObject)
-- Player = class("Player")

function Player:initialize(loc,control)
	super.initialize(self)
	self.location = loc
	-- Control Initialization
	if control == "Online" then
		self:gotoState('OnlinePlayer')
	else
		self:gotoState('LocalPlayer')
		self.upKeyIsDown = false
		self.downKeyIsDown = false
		self.rightKeyIsDown = false
		self.leftKeyIsDown = false
		self.acceptIsDown = false
		self.cancelIsDown = false
		if control == "WASD" or control == "Arrow Keys" or control == "NumPad" then
			self.controlType = "keyboard"
			self:setUpKeys(control)
		else
			self.controlType = "joystick"
			self:setUpController()
		end
	end

end

function Player:draw()
end

local LocalPlayer = Player:addState("LocalPlayer")

function LocalPlayer:update()
	if self.controlType == "keyboard" then
		self:updateKeyboard()
	end
	if self.controlType == "joystick" then
		self:updateJoystick()
	end
end

-- This sets up player keyboard controls based on the selections in the Control Select
function LocalPlayer:setUpKeys(control)
	if control == "WASD" then
		self.upKey = "w"
		self.downKey = "s"
		self.rightKey = "d"
		self.leftKey = "a"
		self.accept = "e"
		self.cancel = "q"
	elseif control == "NumPad" then
		self.upKey = "kp8"
		self.downKey = "kp5"
		self.rightKey = "kp6"
		self.leftKey = "kp4"
		self.accept = "kp9"
		self.cancel = "kp7"
	elseif control == "Arrow Keys" then
		self.upKey = "up"
		self.downKey = "down"
		self.rightKey = "right"
		self.leftKey = "left"
		self.accept = "/"
		self.cancel = "."
	end
end

function LocalPlayer:setUpController()
	self.joystickNumber = string.sub(Game.playerChoice[self.location].control,-1)
end

-- Updates player keyboard controls
function LocalPlayer:updateKeyboard()
	if love.keyboard.isDown( self.upKey ) then
		self.upKeyIsDown = true
	else
		self.upKeyIsDown = false
	end
	if love.keyboard.isDown( self.rightKey ) then
		self.rightKeyIsDown = true
	else
		self.rightKeyIsDown = false
	end
	if love.keyboard.isDown( self.downKey ) then
		self.downKeyIsDown = true
	else
		self.downKeyIsDown = false
	end
	if love.keyboard.isDown( self.leftKey ) then
		self.leftKeyIsDown = true
	else
		self.leftKeyIsDown = false
	end
end

-- updates player joystick controls
function LocalPlayer:updateJoystick()
	local hat = love.joystick.getHat( self.joystickNumber, 0 )
	self.upKeyIsDown = false
	self.downKeyIsDown = false
	self.rightKeyIsDown = false
	self.leftKeyIsDown = false
	self.cancelIsDown = false
	self.acceptIsDown = false
	if hat == "u" then
		self.upKeyIsDown = true
	elseif hat == "d" then
		self.downKeyIsDown = true
	elseif hat == "r" then
		self.rightKeyIsDown = true
	elseif hat == "l" then
		self.leftKeyIsDown = true
	elseif hat == "ld" then
		self.leftKeyIsDown = true
		self.downKeyIsDown = true
	elseif hat == "lu" then
		self.leftKeyIsDown = true
		self.upKeyIsDown = true
	elseif hat == "rd" then
		self.rightKeyIsDown = true
		self.downKeyIsDown = true
	elseif hat == "ru" then
		self.rightKeyIsDown = true
		self.upKeyIsDown = true
	end
	if love.joystick.isDown( self.joystickNumber, 0) then
		self.acceptIsDown = true
	elseif love.joystick.isDown( self.joystickNumber, 1) then
		self.cancelIsDown = true
	end
end

local OnlinePlayer = Player:addState("OnlinePlayer")

function OnlinePlayer:controls()

end
